

.. image:: https://badge.fury.io/py/kerasy.svg
   :target: https://pypi.org/project/kerasy/
   :alt: PyPI version


.. image:: https://badge.fury.io/gh/iwasakishuto%2Fkerasy.svg
   :target: https://github.com/iwasakishuto/Kerasy
   :alt: GitHub version


.. image:: https://img.shields.io/github/license/mashape/apistatus.svg?maxAge=2592000
   :target: https://github.com/iwasakishuto/Kerasy/blob/gh-pages/LICENSE
   :alt: license


Kerasy
======

I want to **deepen my understanding of deep learning** by imitating the sophisticated neural networks API, **Keras**.

Installation
^^^^^^^^^^^^

There are two ways to install Kerasy:


* **Install Kerasy from PyPI (recommended):**
   ::

       $ sudo pip install kerasy

* **Alternatively: install Kerasy from the GitHub source:**
   ::

       $ git clone https://github.com/keras-team/keras.git
       $ cd keras
       $ sudo python setup.py install

Why this name Kerasy
^^^^^^^^^^^^^^^^^^^^

Kerasy means "Keras" + "-y".


* `Keras <#Keras>`_ is a high-level neural networks API, written in Python.
* "-y" is a native English suffix of adjectives meaning **"characterized by or inclined to"** the substance or action of the word or stem to which the suffix is attached. It often plays a role like **"ish"**\ , **"esque"**\ , or **"like"**.

Keras is my favorite library, so I wanted to imitate it and add more algorithms for in particular bioinformatics (which is my major.)

Keras
~~~~~

..

   .. image:: https://s3.amazonaws.com/keras.io/img/keras-logo-2018-large-1200.png
      :target: https://s3.amazonaws.com/keras.io/img/keras-logo-2018-large-1200.png
      :alt: Keras logo


   .. image:: https://travis-ci.org/keras-team/keras.svg?branch=master
      :target: https://travis-ci.org/keras-team/keras
      :alt: Build Status


   .. image:: https://img.shields.io/github/license/mashape/apistatus.svg?maxAge=2592000
      :target: https://github.com/keras-team/keras/blob/master/LICENSE
      :alt: license

   Keras is a high-level neural networks API, written in Python and capable of running on top of `TensorFlow <https://github.com/tensorflow/tensorflow>`_\ , `CNTK <https://github.com/Microsoft/cntk>`_\ , or `Theano <https://github.com/Theano/Theano>`_. It was developed with a focus on enabling fast experimentation. *Being able to go from idea to result with the least possible delay is key to doing good research.*

